Skip to main content Crate eure_document Copy item path Source pub use text::Text ;pub use document::constructor ;data_model Data structure for representing a data-model of Eure. document A data structure for representing a Eure document including extensions. identifier Identifier type and parser. map must_be Zero-sized types for compile-time literal matching in FromEure.
Zero-sized types for compile-time literal matching in FromEure. parse Trait for parsing Rust types from Eure documents.
FromEure trait for parsing Rust types from Eure documents. path Data structure for representing a path in a Eure document. plan Total, verified layout plan: a coverage-checked projection from
document::EureDocument to source::SourceDocument .
Total, verified layout plan for projecting an [EureDocument] to
[SourceDocument]. proxy Proxy types for use with #[eure(via = "...")] attribute.
Proxy types for use with #[eure(via = "...")] attribute. source Source-level document representation with layout metadata. text Unified text type for strings and code.
Text type unifying strings and code in Eure. tree A data structure for representing a Eure document without any span information. value A type-safe data-type of Eure data-model. write Trait for writing Rust types to Eure documents.
IntoEure trait for writing Rust types to Eure documents. eure A declarative macro for building Eure documents, inspired by serde_json’s json! macro. eure_source A macro for building [SourceDocument]s with source layout tracking.