Module layout

Module layout 

Deterministic layout for Eure documents. Generic layout projection for Eure documents.

DocLayout is a source-agnostic, declarative plan describing how document paths should be projected to source constructs.

Structs

DocLayout
Declarative layout plan for projecting a document to source.
LayoutOrderRule
Ordering directive for direct children of a parent path.
LayoutStyleRule
Style directive at a path with optional union constraints.
VariantConstraint
Constraint for style applicability under a union branch.

Enums

LayoutStyle
Preferred layout style for a document path.

Functions

project_with_layout
Project a runtime document to source using a generic layout plan.