Module must_be

Module must_be 

Zero-sized types for compile-time literal matching in FromEure. Zero-sized types for compile-time literal matching in FromEure.

This module provides MustBeText<M>, a zero-sized type that only successfully parses from a specific Text value (content + language). It’s similar to monostate’s MustBe! macro but for Eure’s FromEure trait.

Structs

MustBeText
Zero-sized type that only parses from a specific Text value.

Traits

MustBeTextMarker
Marker trait for MustBeText types.