MustBeText

Struct MustBeText 

pub struct MustBeText<M: MustBeTextMarker>(/* private fields */);
Zero-sized type that only parses from a specific Text value.

This type implements FromEure and succeeds only when the parsed value matches the expected content and has a compatible language.

Use the MustBeText! macro to create instances of this type.

Implementations

Source

impl<M: MustBeTextMarker> MustBeText<M>

pub const fn new() -> Self

Create a new instance.