pub struct BorrowedCow;Expand description
A proxy type that enables borrowing from the document when parsing Cow<'doc, T>.
Unlike the default Cow<'static, T> implementation which always returns Cow::Owned,
this proxy returns Cow::Borrowed by parsing &'doc T directly from the document.
Example
ⓘ
use eure_macros::FromEure;
use std::borrow::Cow;
#[derive(FromEure)]
struct Data<'doc> {
#[eure(via = "eure_document::proxy::BorrowedCow")]
name: Cow<'doc, str>,
}Trait Implementations
Sourceimpl<'doc, T> FromEure<'doc, Cow<'doc, T>> for BorrowedCow
impl<'doc, T> FromEure<'doc, Cow<'doc, T>> for BorrowedCow
Sourceimpl<'a, T> IntoEure<Cow<'a, T>> for BorrowedCow
impl<'a, T> IntoEure<Cow<'a, T>> for BorrowedCow
Sourcetype Error = <<T as ToOwned>::Owned as IntoEure>::Error
type Error = <<T as ToOwned>::Owned as IntoEure>::Error
The error type returned when writing. Read more
Sourcefn write(
value: Cow<'a, T>,
c: &mut DocumentConstructor,
) -> Result<(), Self::Error>
fn write( value: Cow<'a, T>, c: &mut DocumentConstructor, ) -> Result<(), Self::Error>
Write a value to the current node in the document constructor.
Sourcefn write_flatten(
value: T,
rec: &mut RecordWriter<'_>,
) -> Result<(), Self::Error>
fn write_flatten( value: T, rec: &mut RecordWriter<'_>, ) -> Result<(), Self::Error>
Write a value as flattened record fields. Read more