StringStyle

Enum StringStyle 

pub enum StringStyle {
    Quoted,
    Literal,
    DelimitedLitStr(u8),
    DelimitedCode(u8),
}
Syntax style for string keys (for round-trip formatting).

This preserves whether a string key was written with quotes, single quotes, or delimiters, similar to how SyntaxHint preserves code block formatting.

Variants



Quoted

Quoted string: "..."



Literal

Literal string (single-quoted): '...' Content is taken literally, no escape processing



DelimitedLitStr(u8)

Delimited literal string: <'...'>, <<'...'>>, <<<'...'>>> The u8 indicates the delimiter level (1, 2, or 3) Content is taken literally, no escape processing



DelimitedCode(u8)

Delimited code: <>, <<>>, <<<>>> The u8 indicates the delimiter level (1, 2, or 3)