ArrayElementSource

Struct ArrayElementSource 

pub struct ArrayElementSource {
    pub trivia_before: Vec<Trivia>,
    pub index: usize,
    pub trailing_comment: Option<Comment>,
}
Layout information for an array element.

Used to preserve comments that appear before array elements when converting from formats like TOML.

Fields

trivia_before: Vec<Trivia>

Trivia (comments/blank lines) before this element

index: usize

The index of this element in the NodeArray

trailing_comment: Option<Comment>

Trailing comment on the same line as this element

Implementations

Source

impl ArrayElementSource

pub fn new(index: usize) -> Self

Create an array element source.

pub fn with_trivia(self, trivia: Vec<Trivia>) -> Self

Add trivia before this element.

pub fn with_trailing_comment(self, comment: Comment) -> Self

Add a trailing comment.