EureKeys

Struct EureKeys 

pub struct EureKeys(/* private fields */);

Implementations

Source

impl EureKeys

pub fn len(&self) -> usize

Returns the number of elements in the collection.

pub fn is_empty(&self) -> bool

Returns true if the collection contains no elements.

pub fn iter(&self) -> impl Iterator<Item = &TreeKey>

Iterates over the collection.

pub fn capacity(&self) -> usize

Returns the capacity of the collection.

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more elements to be inserted in the collection.

pub fn with_capacity(capacity: usize) -> Self

Construct a new empty collection with the specified capacity.

pub fn new() -> Self

Creates a new, empty collection.

pub fn clear(&mut self)

Clears the collection, removing all values.