Deterministic layout for Eure documents. Generic layout projection for Eure documents.
DocLayout is a source-agnostic, declarative plan describing how document
paths should be projected to source constructs.
Structs
- DocLayout
- Declarative layout plan for projecting a document to source.
- Layout
Order Rule - Ordering directive for direct children of a parent path.
- Layout
Style Rule - Style directive at a path with optional union constraints.
- Variant
Constraint - Constraint for style applicability under a union branch.
Enums
- Layout
Style - Preferred layout style for a document path.
Functions
- project_
with_ layout - Project a runtime document to source using a generic layout plan.