pub enum ArrayIndexKind {
Push,
Current,
Specific(usize),
}Expand description
Kind of array index used in a path segment.
Variants
Push
[] — always pushes a new element onto the array
Current
[^] — references the element most recently pushed into this array
within the current block scope. Errors if there is no such push in scope.
Specific(usize)
[n] — references a specific index, creating the element if it does not exist